@@ -19,8 +19,8 @@ EXEMPTIONS = (
     "tanf_amount_if_eligible",
     "tanf_countable_income",
     "tanf_initial_employment_deduction",
-    "initial_tanf_eligibility",
-    "continuous_tanf_eligibility",
+    "is_tanf_initial_eligible",
+    "is_tanf_continuous_eligible",
     "is_tanf_eligible",
 )
 
