@@ -12,7 +12,7 @@ class per_vehicle_payment(Variable):
     definition_period = YEAR
 
     def formula(person, period, parameters):
-        per_vehicle = parameters(period).states.ca.per_vehicle_payment
+        per_vehicle = parameters(period).gov.states.ca.per_vehicle_payment
         state = person.household("state_code", period)
         vehicles_owned = person("vehicles_owned", period)
         capped_vehicles = min_(vehicles_owned, per_vehicle.max_vehicles[state])
